
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.4'
version = '1.1.4'
full_version = '1.1.4'
git_revision = '0a4af672dacbf9467815270779a54a39755c24dc'
release = True

if not release:
    version = full_version
    short_version += ".dev"
